==> huaweicloudsdkecs-3.0.49-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/list_server_interfaces_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListServerInterfacesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'interface_attachments': 'list[InterfaceAttachment]'
    }

    attribute_map = {
        'interface_attachments': 'interfaceAttachments'
    }

    def __init__(self, interface_attachments=None):
        """ListServerInterfacesResponse - a model defined in huaweicloud sdk"""
        
        super(ListServerInterfacesResponse, self).__init__()

        self._interface_attachments = None
        self.discriminator = None

        if interface_attachments is not None:
            self.interface_attachments = interface_attachments

    @property
    def interface_attachments(self):
        """Gets the interface_attachments of this ListServerInterfacesResponse.

        云服务器网卡信息列表

        :return: The interface_attachments of this ListServerInterfacesResponse.
        :rtype: list[InterfaceAttachment]
        """
        return self._interface_attachments

    @interface_attachments.setter
    def interface_attachments(self, interface_attachments):
        """Sets the interface_attachments of this ListServerInterfacesResponse.

        云服务器网卡信息列表

        :param interface_attachments: The interface_attachments of this ListServerInterfacesResponse.
        :type: list[InterfaceAttachment]
        """
        self._interface_attachments = interface_attachments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListServerInterfacesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkecs-3.0.51-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/list_server_interfaces_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListServerInterfacesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'interface_attachments': 'list[InterfaceAttachment]'
    }

    attribute_map = {
        'interface_attachments': 'interfaceAttachments'
    }

    def __init__(self, interface_attachments=None):
        """ListServerInterfacesResponse - a model defined in huaweicloud sdk"""
        
        super(ListServerInterfacesResponse, self).__init__()

        self._interface_attachments = None
        self.discriminator = None

        if interface_attachments is not None:
            self.interface_attachments = interface_attachments

    @property
    def interface_attachments(self):
        """Gets the interface_attachments of this ListServerInterfacesResponse.

        云服务器网卡信息列表

        :return: The interface_attachments of this ListServerInterfacesResponse.
        :rtype: list[InterfaceAttachment]
        """
        return self._interface_attachments

    @interface_attachments.setter
    def interface_attachments(self, interface_attachments):
        """Sets the interface_attachments of this ListServerInterfacesResponse.

        云服务器网卡信息列表

        :param interface_attachments: The interface_attachments of this ListServerInterfacesResponse.
        :type: list[InterfaceAttachment]
        """
        self._interface_attachments = interface_attachments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListServerInterfacesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
